<template>
  <div class="app-container">
    <div class="oilContainer">
      <el-card>
        <div slot="header">
          <span><i class="el-icon-data-line"></i>油表数据</span>
        </div>
        <div>
          <el-row>
            <el-col :span="6" class="card-box">
              <el-card>
                <div slot="header">
                  <span><i class="el-icon-pie-chart"></i> 数据处理统计</span>
                </div>
                <div class="container">
                  <div ref="oilPie" style="height: 300px" />
                </div>
              </el-card>
            </el-col>

            <el-col :span="8" class="card-box">
              <el-card>
                <div slot="header">
                  <span><i class="el-icon-data-line"></i> 操作统计</span>
                </div>
                <div class="container">
                  <div ref="oilLine" style="height: 300px" />
                </div>
              </el-card>
            </el-col>
            <el-col :span="10" class="card-box">
              <el-card>
                <div slot="header">
                  <span><i class="el-icon-tickets"></i> 接口调用</span>
                </div>
                <div class="container">
                  <dv-scroll-board :config="oilConfig" style="height: 300px" />
                </div>
              </el-card>
            </el-col>
          </el-row>
        </div>
      </el-card>
    </div>
    <div class="waterContainer">
      <el-card>
        <div slot="header">
          <span><i class="el-icon-data-line"></i>水表数据</span>
        </div>
        <div>
          <el-row>
            <el-col :span="6" class="card-box">
              <el-card>
                <div slot="header">
                  <span><i class="el-icon-pie-chart"></i> 数据处理统计</span>
                </div>
                <div class="container">
                  <div ref="waterPie" style="height: 300px" />
                </div>
              </el-card>
            </el-col>

            <el-col :span="8" class="card-box">
              <el-card>
                <div slot="header">
                  <span><i class="el-icon-data-line"></i> 操作统计</span>
                </div>
                <div class="container">
                  <div ref="waterLine" style="height: 300px" />
                </div>
              </el-card>
            </el-col>
            <el-col :span="10" class="card-box">
              <el-card>
                <div slot="header">
                  <span><i class="el-icon-tickets"></i> 接口调用</span>
                </div>
                <div class="container">
                  <dv-scroll-board :config="WaterConfig" style="height: 300px" />
                </div>
              </el-card>
            </el-col>
          </el-row>
        </div>
      </el-card>
    </div>
    <div class="eleContainer">
      <el-card>
        <div slot="header">
          <span><i class="el-icon-data-line"></i>电表数据</span>
        </div>
        <div>
          <el-row>
            <el-col :span="6" class="card-box">
              <el-card>
                <div slot="header">
                  <span><i class="el-icon-pie-chart"></i> 数据处理统计</span>
                </div>
                <div class="container">
                  <div ref="elePie" style="height: 300px" />
                </div>
              </el-card>
            </el-col>

            <el-col :span="8" class="card-box">
              <el-card>
                <div slot="header">
                  <span><i class="el-icon-data-line"></i> 操作统计</span>
                </div>
                <div class="container">
                  <div ref="eleLine" style="height: 300px" />
                </div>
              </el-card>
            </el-col>
            <el-col :span="10" class="card-box">
              <el-card>
                <div slot="header">
                  <span><i class="el-icon-tickets"></i> 接口调用</span>
                </div>
                <div class="container">
                  <dv-scroll-board :config="eleConfig" style="height: 300px" />
                </div>
              </el-card>
            </el-col>
          </el-row>
        </div>
      </el-card>
    </div>
  </div>
</template>

<script>
import { getCount, getLineData, getOperList } from "@/api/manage/clean";
import * as echarts from "echarts";
import dayjs from "dayjs";
export default {
  name: "Cache",
  data() {
    return {
      waterPie: null,
      waterLine: null,
      WaterConfig: {},
      elePie: null,
      eleLine: null,
      eleConfig: {},
      oilPie: null,
      oilLine: null,
      oilConfig: {},
    };
  },
  created() {
    this.getWaterList();
    this.getEleList();
    this.getOilList();
  },
  methods: {
    /** 查信息 */
    getWaterList() {
      let startTime = dayjs().subtract(7, "day").format("YYYY-MM-DD");
      let endTime = dayjs().format("YYYY-MM-DD");
      getCount({
        title: "水表数据",
      }).then((response) => {
        if (response.code == 200) {
          let raw = response.data.rawCount;
          let processed = response.data.processedData;
          let last = raw - processed;
          this.waterPie = echarts.init(this.$refs.waterPie, "macarons");
          this.waterPie.setOption({
            tooltip: {
              trigger: "item",
            },
            grid: {
              left: "5%",
              right: "5%",
              top: "5%",
              bottom: "5%",
              containLabel: true,
            },
            legend: {},
            series: [
              {
                name: "数据处理统计",
                type: "pie",
                radius: [5, 90],
                center: ["50%", "48%"],
                itemStyle: {
                  borderRadius: 10,
                  borderColor: "#fff",
                  borderWidth: 2,
                },
                //data: response.data.commandStats,
                data: [
                  { value: processed, name: "已处理" },
                  { value: last, name: "未处理" },
                ],
                animationEasing: "cubicInOut",
                animationDuration: 1000,
              },
            ],
          });
        } else {
          this.$message.error("获取水表数据报错");
        }
      });
      getLineData({
        title: "水表数据",
        startTime,
        endTime,
      }).then((res) => {
        if (res.code == 200) {
          //dateTime: "2025-04-20", insertCount: 0, updateCount: 0, deleteCount: 0
          let dateArr = [];
          let insertArr = [];
          let updateArr = [];
          let deleteArr = [];
          res.data.forEach((item) => {
            dateArr.push(item.dateTime);
            insertArr.push(item.insertCount);
            updateArr.push(item.updateCount);
            deleteArr.push(item.deleteCount);
          });
          this.waterLine = echarts.init(this.$refs.waterLine, "macarons");
          this.waterLine.setOption({
            tooltip: {
              trigger: "axis",
            },
            legend: {
              data: ["新增", "编辑", "删除"],
            },
            xAxis: {
              type: "category",
              boundaryGap: false,
              data: dateArr,
            },
            yAxis: {
              type: "value",
            },
            series: [
              {
                name: "新增",
                type: "line",
                data: insertArr,
              },
              {
                name: "编辑",
                type: "line",
                data: updateArr,
              },
              {
                name: "删除",
                type: "line",
                data: deleteArr,
              },
            ],
          });
        } else {
          this.$message.error("获取水表数据报错");
        }
      });
      getOperList({
        pageNum: 1,
        pageSize: 20,
        title: "水表数据",
      }).then((res) => {
        if (res.code == 200) {
          let configData = [];
          res.data.rows.forEach((item, index) => {
            let json = JSON.parse(item.jsonResult);
            configData.push([
              index + 1,
              item.title,
              json.data,
              item.operName,
              item.operTime,
            ]);
          });
          this.WaterConfig = {
            header: ["编号", "名称", "数量", "用户名", "操作时间"],
            rowNum: 8,
            columnWidth: [60, 120, 60],
            align: ["center", "center", "center", "center", "center"],
            headerBGC: "#ffffff",
            oddRowBGC: "#ffffff",
            evenRowBGC: "#f6f8fa",
            data: configData,
          };
        } else {
          this.$message.error("获取水表数据报错");
        }
      });
    },
    getEleList() {
      let startTime = dayjs().subtract(7, "day").format("YYYY-MM-DD");
      let endTime = dayjs().format("YYYY-MM-DD");
      getCount({
        title: "电表数据",
      }).then((response) => {
        if (response.code == 200) {
          let raw = response.data.rawCount;
          let processed = response.data.processedData;
          let last = raw - processed;
          this.elePie = echarts.init(this.$refs.elePie, "macarons");
          this.elePie.setOption({
            tooltip: {
              trigger: "item",
            },
            grid: {
              left: "5%",
              right: "5%",
              top: "5%",
              bottom: "5%",
              containLabel: true,
            },
            legend: {},
            series: [
              {
                name: "数据处理统计",
                type: "pie",
                radius: [5, 90],
                center: ["50%", "48%"],
                itemStyle: {
                  borderRadius: 10,
                  borderColor: "#fff",
                  borderWidth: 2,
                },
                //data: response.data.commandStats,
                data: [
                  { value: processed, name: "已处理" },
                  { value: last, name: "未处理" },
                ],
                animationEasing: "cubicInOut",
                animationDuration: 1000,
              },
            ],
          });
        } else {
          this.$message.error("获取电表数据报错");
        }
      });
      getLineData({
        title: "电表数据",
        startTime,
        endTime,
      }).then((res) => {
        if (res.code == 200) {
          //dateTime: "2025-04-20", insertCount: 0, updateCount: 0, deleteCount: 0
          let dateArr = [];
          let insertArr = [];
          let updateArr = [];
          let deleteArr = [];
          res.data.forEach((item) => {
            dateArr.push(item.dateTime);
            insertArr.push(item.insertCount);
            updateArr.push(item.updateCount);
            deleteArr.push(item.deleteCount);
          });
          this.eleLine = echarts.init(this.$refs.eleLine, "macarons");
          this.eleLine.setOption({
            tooltip: {
              trigger: "axis",
            },
            legend: {
              data: ["新增", "编辑", "删除"],
            },
            xAxis: {
              type: "category",
              boundaryGap: false,
              data: dateArr,
            },
            yAxis: {
              type: "value",
            },
            series: [
              {
                name: "新增",
                type: "line",
                data: insertArr,
              },
              {
                name: "编辑",
                type: "line",
                data: updateArr,
              },
              {
                name: "删除",
                type: "line",
                data: deleteArr,
              },
            ],
          });
        } else {
          this.$message.error("获取电表数据报错");
        }
      });
      getOperList({
        pageNum: 1,
        pageSize: 20,
        title: "电表数据",
      }).then((res) => {
        if (res.code == 200) {
          let configData = [];
          res.data.rows.forEach((item, index) => {
            let json = JSON.parse(item.jsonResult);
            configData.push([
              index + 1,
              item.title,
              json.data,
              item.operName,
              item.operTime,
            ]);
          });
          this.eleConfig = {
            header: ["编号", "名称", "数量", "用户名", "操作时间"],
            rowNum: 8,
            columnWidth: [60, 120, 60],
            align: ["center", "center", "center", "center", "center"],
            headerBGC: "#ffffff",
            oddRowBGC: "#ffffff",
            evenRowBGC: "#f6f8fa",
            data: configData,
          };
        } else {
          this.$message.error("获取电表数据报错");
        }
      });
    },
    getOilList() {
      let startTime = dayjs().subtract(7, "day").format("YYYY-MM-DD");
      let endTime = dayjs().format("YYYY-MM-DD");
      getCount({
        title: "油表数据",
      }).then((response) => {
        if (response.code == 200) {
          let raw = response.data.rawCount;
          let processed = response.data.processedData;
          let last = raw - processed;
          this.oilPie = echarts.init(this.$refs.oilPie, "macarons");
          this.oilPie.setOption({
            tooltip: {
              trigger: "item",
            },
            grid: {
              left: "5%",
              right: "5%",
              top: "5%",
              bottom: "5%",
              containLabel: true,
            },
            legend: {},
            series: [
              {
                name: "数据处理统计",
                type: "pie",
                radius: [5, 90],
                center: ["50%", "48%"],
                itemStyle: {
                  borderRadius: 10,
                  borderColor: "#fff",
                  borderWidth: 2,
                },
                //data: response.data.commandStats,
                data: [
                  { value: processed, name: "已处理" },
                  { value: last, name: "未处理" },
                ],
                animationEasing: "cubicInOut",
                animationDuration: 1000,
              },
            ],
          });
        } else {
          this.$message.error("获取油表数据报错");
        }
      });
      getLineData({
        title: "油表数据",
        startTime,
        endTime,
      }).then((res) => {
        if (res.code == 200) {
          //dateTime: "2025-04-20", insertCount: 0, updateCount: 0, deleteCount: 0
          let dateArr = [];
          let insertArr = [];
          let updateArr = [];
          let deleteArr = [];
          res.data.forEach((item) => {
            dateArr.push(item.dateTime);
            insertArr.push(item.insertCount);
            updateArr.push(item.updateCount);
            deleteArr.push(item.deleteCount);
          });
          this.oilLine = echarts.init(this.$refs.oilLine, "macarons");
          this.oilLine.setOption({
            tooltip: {
              trigger: "axis",
            },
            legend: {
              data: ["新增", "编辑", "删除"],
            },
            xAxis: {
              type: "category",
              boundaryGap: false,
              data: dateArr,
            },
            yAxis: {
              type: "value",
            },
            series: [
              {
                name: "新增",
                type: "line",
                data: insertArr,
              },
              {
                name: "编辑",
                type: "line",
                data: updateArr,
              },
              {
                name: "删除",
                type: "line",
                data: deleteArr,
              },
            ],
          });
        } else {
          this.$message.error("获取油表数据报错");
        }
      });
      getOperList({
        pageNum: 1,
        pageSize: 20,
        title: "油表数据",
      }).then((res) => {
        if (res.code == 200) {
          let configData = [];
          res.data.rows.forEach((item, index) => {
            let json = JSON.parse(item.jsonResult);
            configData.push([
              index + 1,
              item.title,
              json.data,
              item.operName,
              item.operTime,
            ]);
          });
          this.oilConfig = {
            header: ["编号", "名称", "数量", "用户名", "操作时间"],
            rowNum: 8,
            columnWidth: [60, 120, 60],
            align: ["center", "center", "center", "center", "center"],
            headerBGC: "#ffffff",
            oddRowBGC: "#ffffff",
            evenRowBGC: "#f6f8fa",
            data: configData,
          };
        } else {
          this.$message.error("获取油表数据报错");
        }
      });
    },
  },
};
</script>

<style scoped lang="scss">
.waterContainer {
  margin-top: 15px;
}

.eleContainer {
  margin-top: 15px;
}
.dv-scroll-board {
  color: black !important;
}
</style>
